[<img height="23" src="https://github.com/lh9171338/Outline/blob/master/icon.jpg"/>](https://github.com/lh9171338/Outline) lh-webtool
===

This is a web tool package.

# Updates

 - [x] 2024.03.24: Add `Crawler` and `play_image_web` module

# Tools

* crawler
    * Crawler
* play_image_web

# Install

* Installing from source
```shell
git clone https://github.com/lh9171338/lh-webtool.git

cd lh-webtool

python -m build

pip install dist/lh_webtool-1.0.0-py3-none-any.whl
```

* Install from the Python Package Index (PyPI)
```shell
pip install lh_webtool
```
